package wdpress.tapestry.upload;

import java.io.BufferedInputStream;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileOutputStream;

import org.apache.tapestry.IAsset;
import org.apache.tapestry.IRequestCycle;
import org.apache.tapestry.html.BasePage;
import org.apache.tapestry.request.IUploadFile;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class PicturePage extends BasePage  {

  private static final Log log = LogFactory.getLog( PicturePage.class );

  private static File pictDir;

  private byte[]      buff = new byte[ 4096 ];
  private IUploadFile file;
  private String      type;
  private String      fileName;

  public IUploadFile getFile()                    {  return file;       }
  public void        setFile( IUploadFile file )  {  this.file = file;  }

  public String      getFileName()                {  return fileName;   }

  public IAsset getPictureAsset()  {
    log.info( "getPictureAsset" );
    log.info( "fileName = " + fileName + ", type = " + type );
    return  new PictureAsset( fileName, type );
  }

  public void initialize()  {
    log.info( "initialize" );
  }

  public void detach()  {
    log.info( "detach" );
    super.detach();
  }

  public void formSubmit( IRequestCycle requestCycle )  {
    log.info( "formSubmit" );
    if ( pictDir == null )  {
      pictDir = new File( 
        PictureService.getPictPath( requestCycle, PictureService.PICTURE_PATH )
      );
    }
    type     = file.getContentType();
    fileName = file.getFileName();
    savePicture( file, pictDir.getPath() + File.separator + fileName );
    log.info( "fileName = " + file.getFileName()
              + ", type = "   + file.getContentType() );
  }

  private void savePicture( IUploadFile inFile, String outFile )  {
    log.info( "savePicture" );
    try  {
      BufferedInputStream in = new BufferedInputStream( inFile.getStream() );
      DataOutputStream out =
                  new DataOutputStream( new FileOutputStream( outFile ) );
      int len, sum = 0;
      while( ( len = in.read( buff, 0, buff.length ) ) >= 0 )  {
        out.write( buff, 0, len );
        out.flush();
        sum += len;
      }
      out.close();
      in.close();
      log.info( "sum = " + sum );
    }  catch( Exception ex )  {
      log.warn( ex.getMessage() );
    }
  }

}